@@ -39,8 +39,13 @@
 #include <X11/keysym.h>
 #include <X11/Xatom.h>
 #include <gst/gst.h>
+#if GST_CHECK_VERSION(1,0,0)
+#include <gst/video/videooverlay.h>
+#include <gst/video/colorbalance.h>
+#else
 #include <gst/interfaces/xoverlay.h>
 #include <gst/interfaces/colorbalance.h>
+#endif
 
 static char                 configfile[2048];
 
@@ -76,7 +81,11 @@ static const char          *vcd_device;
 static GstElement          *gst_elm_play;
 static GstBus              *gst_bus;
 static unsigned int /*GstMessageType*/       ignore_messages_mask;
+#if GST_CHECK_VERSION(1,0,0)
+static GstVideoOverlay     *xoverlay;
+#else
 static GstXOverlay         *xoverlay;
+#endif
 static GstColorBalance     *color_balance;
 static gulong               gst_bus_sync;
 static gulong               gst_bus_async;
@@ -121,7 +130,11 @@ gstCapsSet (GstPad *pad,
             GParamSpec * /*pspec*/,
             gpointer /*data*/)
 {
+#if GST_CHECK_VERSION(1,0,0)
+    GstCaps *caps = gst_pad_get_current_caps (pad);
+#else
     GstCaps *caps = gst_pad_get_negotiated_caps (pad);
+#endif
     if (!caps)
         return;
     TQApplication::postEvent (gstapp, new TQEvent ((TQEvent::Type) event_video));
@@ -200,7 +213,13 @@ static void gstSource (GObject *, GParamSpec *, gpointer /*data*/) {
 static void gstGetDuration () {
     GstFormat fmt = GST_FORMAT_TIME;
     gint64 len = -1; // usec
-    if (gst_element_query_duration (gst_elm_play, &fmt, &len))
+    if (gst_element_query_duration (gst_elm_play,
+#if GST_CHECK_VERSION(1,0,0)
+                fmt,
+#else
+                &fmt,
+#endif
+                &len))
         if (movie_length != len / (GST_MSECOND * 100)) {
             movie_length = len / (GST_MSECOND * 100);
             fprintf (stderr, "new length %d\n", movie_length);
@@ -245,13 +264,23 @@ static void gstBusMessage (GstBus *, GstMessage * message, gpointer) {
             break;
         case GST_MESSAGE_BUFFERING: {
             gint percent = 0;
-            gst_structure_get_int (message->structure, "buffer-percent", &percent);
+            gst_structure_get_int (
+#if GST_CHECK_VERSION(1,0,0)
+                gst_message_get_structure(message),
+#else
+                message->structure,
+#endif
+                "buffer-percent", &percent);
             TQApplication::postEvent (gstapp, new GstProgressEvent (percent));
             //fprintf (stderr, "Buffering message (%u%%)\n", percent);
             break;
         }
         case GST_MESSAGE_APPLICATION: {
+#if GST_CHECK_VERSION(1,0,0)
+            const char * msg = gst_structure_get_name (gst_message_get_structure(message));
+#else
             const char * msg = gst_structure_get_name (message->structure);
+#endif
             fprintf (stderr, "app msg %s\n", msg ? msg : "<unknown>");
             //gst_structure_foreach (message->structure, gstStructure, 0L);
             break;
@@ -297,10 +326,21 @@ static void gstBusMessage (GstBus *, GstMessage * message, gpointer) {
 }
 
 static void gstMessageElement (GstBus *, GstMessage *msg, gpointer /*data*/) {
-    if (gst_structure_has_name (msg->structure, "prepare-xwindow-id")) {
+    if (gst_structure_has_name (
+#if GST_CHECK_VERSION(1,0,0)
+            gst_message_get_structure(msg),
+#else
+            msg->structure,
+#endif
+            "prepare-xwindow-id")) {
         fprintf (stderr, "prepare-xwindow-id\n");
-        if (xoverlay)
+        if (xoverlay) {
+#if GST_CHECK_VERSION(1,0,0)
+            gst_video_overlay_set_window_handle (xoverlay, wid);
+#else
             gst_x_overlay_set_xwindow_id (xoverlay, wid);
+#endif
+        }
     }
 }
 
@@ -421,7 +461,7 @@ void Backend::play (int repeat) {
 }
 
 void Backend::stop () {
-    TQTimer::singleShot (0, gstapp, TQT_SLOT (stop ()));
+    TQTimer::singleShot (0, gstapp, TQ_SLOT (stop ()));
 }
 
 void Backend::pause () {
@@ -467,7 +507,7 @@ void Backend::quit () {
     if (running)
         stop ();
     else
-        TQTimer::singleShot (0, tqApp, TQT_SLOT (quit ()));
+        TQTimer::singleShot (0, tqApp, TQ_SLOT (quit ()));
 }
 
 bool updateConfigEntry (const TQString & name, const TQString & value) {
@@ -598,13 +638,25 @@ void KGStreamerPlayer::play (int repeat) {
         goto fail;
     if (GST_IS_BIN (videosink))
         element = gst_bin_get_by_interface (GST_BIN (videosink),
-                GST_TYPE_X_OVERLAY);
+#if GST_CHECK_VERSION(1,0,0)
+                GST_TYPE_VIDEO_OVERLAY
+#else
+                GST_TYPE_X_OVERLAY
+#endif
+                );
     else
         element = videosink;
+#if GST_CHECK_VERSION(1,0,0)
+    if (GST_IS_VIDEO_OVERLAY (element)) {
+        xoverlay = GST_VIDEO_OVERLAY (element);
+        gst_video_overlay_set_window_handle (xoverlay, wid);
+    }
+#else
     if (GST_IS_X_OVERLAY (element)) {
         xoverlay = GST_X_OVERLAY (element);
         gst_x_overlay_set_xwindow_id (xoverlay, wid);
     }
+#endif
     gst_element_set_bus (videosink, gst_bus);
     gst_element_set_state (videosink, GST_STATE_READY);
     success = gstPollForStateChange (videosink, GST_STATE_READY);
@@ -621,7 +673,11 @@ void KGStreamerPlayer::play (int repeat) {
             "video-sink",  videosink,
             "audio-sink",  audiosink,
             NULL);
+#if GST_CHECK_VERSION(1,0,0)
+    gst_bus_set_sync_handler (gst_bus, gst_bus_sync_signal_handler, 0L, 0L);
+#else
     gst_bus_set_sync_handler (gst_bus, gst_bus_sync_signal_handler, 0L);
+#endif
     gst_bus_sync = g_signal_connect (gst_bus, "sync-message::element",
             G_CALLBACK (gstMessageElement), 0L);
     g_signal_connect (gst_elm_play, "notify::source",
@@ -653,7 +709,7 @@ void KGStreamerPlayer::play (int repeat) {
         gstPollForStateChange (gst_elm_play, GST_STATE_PLAYING);
     }
     g_free (uri);
-    TQTimer::singleShot (500, this, TQT_SLOT (updatePosition ()));
+    TQTimer::singleShot (500, this, TQ_SLOT (updatePosition ()));
     return;
 fail:
     if (videosink) {
@@ -701,7 +757,7 @@ void KGStreamerPlayer::stop () {
 }
 
 void KGStreamerPlayer::finished () {
-    TQTimer::singleShot (10, this, TQT_SLOT (stop ()));
+    TQTimer::singleShot (10, this, TQ_SLOT (stop ()));
 }
 
 static void adjustColorSetting (const char * channel, int val) {
@@ -750,7 +806,7 @@ void KGStreamerPlayer::seek (int val /*offset_in_deciseconds*/) {
 void KGStreamerPlayer::volume (int val) {
     //fprintf (stderr, "position %d\n", val);
     if (gst_elm_play)
-        g_object_set (G_OBJECT (gst_elm_play), "volume", 1.0*val/100, 0L);
+        g_object_set (G_OBJECT (gst_elm_play), "volume", 1.0*val/100, NULL);
 }
 
 void KGStreamerPlayer::updatePosition () {
@@ -766,11 +822,17 @@ void KGStreamerPlayer::updatePosition () {
         if (gst_elm_play && callback) {
             GstFormat fmt = GST_FORMAT_TIME;
             gint64 val = 0; // usec
-            if (gst_element_query_position (gst_elm_play, &fmt, &val))
+            if (gst_element_query_position (gst_elm_play,
+#if GST_CHECK_VERSION(1,0,0)
+                        fmt,
+#else
+                        &fmt,
+#endif
+                        &val))
                 callback->moviePosition (int (val / (GST_MSECOND * 100)));
         }
         mutex.unlock ();
-        TQTimer::singleShot (500, this, TQT_SLOT (updatePosition ()));
+        TQTimer::singleShot (500, this, TQ_SLOT (updatePosition ()));
     }
 }
 
@@ -797,7 +859,7 @@ bool KGStreamerPlayer::event (TQEvent * e) {
             if (callback)
                 callback->finished ();
             else
-                TQTimer::singleShot (0, this, TQT_SLOT (quit ()));
+                TQTimer::singleShot (0, this, TQ_SLOT (quit ()));
             break;
         }
                 //callback->movieParams (se->length/100, se->width, se->height, se->height ? 1.0*se->width/se->height : 1.0);
@@ -888,11 +950,19 @@ protected:
                         if (gst_elm_play) {
                             GstElement *videosink;
                             g_object_get (gst_elm_play, "video-sink", &videosink, NULL);
+#if GST_CHECK_VERSION(1,0,0)
+                            if (videosink && GST_IS_VIDEO_OVERLAY (videosink)) {
+                                gst_video_overlay_set_window_handle (GST_VIDEO_OVERLAY (videosink), wid);
+                                gst_video_overlay_expose (GST_VIDEO_OVERLAY (videosink));
+                                gst_object_unref (videosink);
+                            }
+#else
                             if (videosink && GST_IS_X_OVERLAY (videosink)) {
                                 gst_x_overlay_set_xwindow_id (GST_X_OVERLAY (videosink), wid);
                                 gst_x_overlay_expose (GST_X_OVERLAY (videosink));
                                 gst_object_unref (videosink);
                             }
+#endif
                         }
                         mutex.unlock ();
                     }
@@ -900,8 +970,15 @@ protected:
 
                 case ConfigureNotify:
                     mutex.lock ();
-                    if (xoverlay && GST_IS_X_OVERLAY (xoverlay))
+#if GST_CHECK_VERSION(1,0,0)
+                    if (xoverlay && GST_IS_VIDEO_OVERLAY (xoverlay)) {
+                        gst_video_overlay_expose (xoverlay);
+                    }
+#else
+                    if (xoverlay && GST_IS_X_OVERLAY (xoverlay)) {
                         gst_x_overlay_expose (xoverlay);
+                    }
+#endif
                     mutex.unlock ();
                     break;
                 case ButtonPress: {
@@ -998,7 +1075,7 @@ int main(int argc, char **argv) {
             getConfigEntries (buf);
         callback->started (dcopclient.appId (), buf);
     } else
-        TQTimer::singleShot (10, gstapp, TQT_SLOT (play (int)));
+        TQTimer::singleShot (10, gstapp, TQ_SLOT (play (int)));
 
     gstapp->exec ();
 
