@@ -23,7 +23,7 @@
 #include <config.h>
 #endif
 
-#include <kapp.h>
+#include <tdeapplication.h>
 #include <tdemainwindow.h>
 #include <tdeaccel.h>
 #include <tdeaction.h>
