@@ -117,7 +117,7 @@ KDE_NO_CDTOR_EXPORT KMPlayerFactory::~KMPlayerFactory () {
     delete s_instance;
 }
 
-KDE_NO_EXPORT KParts::Part *KMPlayerFactory::createPartObject
+TDE_NO_EXPORT KParts::Part *KMPlayerFactory::createPartObject
   (TQWidget *wparent, const char *wname,
    TQObject *parent, const char * name,
    const char * cls, const TQStringList & args) {
@@ -392,16 +392,16 @@ KDE_NO_CDTOR_EXPORT KMPlayerPart::~KMPlayerPart () {
     m_config = 0L;
 }
 
-KDE_NO_EXPORT bool KMPlayerPart::allowRedir (const KURL & url) const {
+TDE_NO_EXPORT bool KMPlayerPart::allowRedir (const KURL & url) const {
     return kapp->authorizeURLAction ("redirect", m_docbase, url);
 }
 
-KDE_NO_EXPORT void KMPlayerPart::setAutoControls (bool b) {
+TDE_NO_EXPORT void KMPlayerPart::setAutoControls (bool b) {
     m_auto_controls = b;
     m_view->controlPanel ()->setAutoControls (b);
 }
 
-KDE_NO_EXPORT void KMPlayerPart::viewerPartDestroyed (TQObject * o) {
+TDE_NO_EXPORT void KMPlayerPart::viewerPartDestroyed (TQObject * o) {
     if (o == m_master)
         m_master = 0L;
     kdDebug () << "KMPlayerPart(" << this << ")::viewerPartDestroyed" << endl;
@@ -411,14 +411,14 @@ KDE_NO_EXPORT void KMPlayerPart::viewerPartDestroyed (TQObject * o) {
         (*i)->updatePlayerMenu (m_view->controlPanel ());
 }
 
-KDE_NO_EXPORT void KMPlayerPart::viewerPartProcessChanged (const char *) {
+TDE_NO_EXPORT void KMPlayerPart::viewerPartProcessChanged (const char *) {
     const KMPlayerPartList::iterator e =kmplayerpart_static->partlist.end();
     KMPlayerPartList::iterator i = std::find_if (kmplayerpart_static->partlist.begin (), e, GroupPredicate (this, m_group));
     if (i != e && *i != this)
         (*i)->updatePlayerMenu (m_view->controlPanel ());
 }
 
-KDE_NO_EXPORT void KMPlayerPart::viewerPartSourceChanged(Source *o, Source *s) {
+TDE_NO_EXPORT void KMPlayerPart::viewerPartSourceChanged(Source *o, Source *s) {
     kdDebug () << "KMPlayerPart::source changed " << m_master << endl;
     if (m_master && m_view) {
         connectSource (o, s);
@@ -426,7 +426,7 @@ KDE_NO_EXPORT void KMPlayerPart::viewerPartSourceChanged(Source *o, Source *s) {
     }
 }
 
-KDE_NO_EXPORT bool KMPlayerPart::openURL (const KURL & _url) {
+TDE_NO_EXPORT bool KMPlayerPart::openURL (const KURL & _url) {
     kdDebug () << "KMPlayerPart::openURL " << _url.url() << endl;
     Source * urlsource = m_sources ["urlsource"];
     KMPlayerHRefSource * hrefsource = static_cast <KMPlayerHRefSource *>(m_sources ["hrefsource"]);
@@ -506,14 +506,14 @@ KDE_NO_EXPORT bool KMPlayerPart::openURL (const KURL & _url) {
     return true;
 }
 
-KDE_NO_EXPORT bool KMPlayerPart::openNewURL (const KURL & url) {
+TDE_NO_EXPORT bool KMPlayerPart::openNewURL (const KURL & url) {
     m_file_name.truncate (0);
     m_havehref = false;
     m_sources ["urlsource"]->setAutoPlay (true);
     return openURL (url);
 }
 
-KDE_NO_EXPORT void KMPlayerPart::waitForImageWindowTimeOut () {
+TDE_NO_EXPORT void KMPlayerPart::waitForImageWindowTimeOut () {
     if (!m_master) {
         // still no ImageWindow attached, eg. audio only
         const KMPlayerPartList::iterator e =kmplayerpart_static->partlist.end();
@@ -536,7 +536,7 @@ KDE_NO_EXPORT void KMPlayerPart::waitForImageWindowTimeOut () {
     }
 }
 
-KDE_NO_EXPORT bool KMPlayerPart::closeURL () {
+TDE_NO_EXPORT bool KMPlayerPart::closeURL () {
     if (!m_group.isEmpty ()) {
         kmplayerpart_static->partlist.remove (this);
         m_group.truncate (0);
@@ -544,7 +544,7 @@ KDE_NO_EXPORT bool KMPlayerPart::closeURL () {
     return PartBase::closeURL ();
 }
 
-KDE_NO_EXPORT void KMPlayerPart::connectToPart (KMPlayerPart * m) {
+TDE_NO_EXPORT void KMPlayerPart::connectToPart (KMPlayerPart * m) {
     m_master = m;
     m->connectPanel (m_view->controlPanel ());
     m->updatePlayerMenu (m_view->controlPanel ());
@@ -567,7 +567,7 @@ KDE_NO_EXPORT void KMPlayerPart::connectToPart (KMPlayerPart * m) {
     }
 }
 
-KDE_NO_EXPORT void KMPlayerPart::setLoaded (int percentage) {
+TDE_NO_EXPORT void KMPlayerPart::setLoaded (int percentage) {
     PartBase::setLoaded (percentage);
     if (percentage < 100) {
         m_browserextension->setLoadingProgress (percentage);
@@ -576,7 +576,7 @@ KDE_NO_EXPORT void KMPlayerPart::setLoaded (int percentage) {
     }
 }
 
-KDE_NO_EXPORT void KMPlayerPart::playingStarted () {
+TDE_NO_EXPORT void KMPlayerPart::playingStarted () {
     const KMPlayerPartList::iterator e =kmplayerpart_static->partlist.end();
     KMPlayerPartList::iterator i = std::find_if (kmplayerpart_static->partlist.begin (), e, GroupPredicate (this, m_group));
     if (i != e && *i != this && m_view && (*i)->source()) {
@@ -600,7 +600,7 @@ KDE_NO_EXPORT void KMPlayerPart::playingStarted () {
     m_browserextension->infoMessage (i18n("KMPlayer: Playing"));
 }
 
-KDE_NO_EXPORT void KMPlayerPart::playingStopped () {
+TDE_NO_EXPORT void KMPlayerPart::playingStopped () {
     KMPlayer::PartBase::playingStopped ();
     if (m_started_emited) {
         m_started_emited = false;
@@ -615,7 +615,7 @@ KDE_NO_EXPORT void KMPlayerPart::playingStopped () {
         m_view->controlPanel ()->setPlaying (false);
 }
 
-KDE_NO_EXPORT void KMPlayerPart::setMenuZoom (int id) {
+TDE_NO_EXPORT void KMPlayerPart::setMenuZoom (int id) {
     int w = 0, h = 0;
     if (m_source)
         m_source->dimensions (w, h);
@@ -637,7 +637,7 @@ KDE_NO_EXPORT void KMPlayerPart::setMenuZoom (int id) {
                                          int (scale * m_view->viewer ()->height()));
 }
 
-KDE_NO_EXPORT void KMPlayerPart::statusPosition (int pos, int length) {
+TDE_NO_EXPORT void KMPlayerPart::statusPosition (int pos, int length) {
     int left = (length - pos) / 10;
     if (left != last_time_left) {
         last_time_left = left;
@@ -661,32 +661,32 @@ KDE_NO_CDTOR_EXPORT KMPlayerBrowserExtension::KMPlayerBrowserExtension (KMPlayer
   : KParts::BrowserExtension (parent, "KMPlayer Browser Extension") {
 }
 
-KDE_NO_EXPORT void KMPlayerBrowserExtension::urlChanged (const TQString & url) {
+TDE_NO_EXPORT void KMPlayerBrowserExtension::urlChanged (const TQString & url) {
     emit setLocationBarURL (url);
 }
 
-KDE_NO_EXPORT void KMPlayerBrowserExtension::setLoadingProgress (int percentage) {
+TDE_NO_EXPORT void KMPlayerBrowserExtension::setLoadingProgress (int percentage) {
     emit loadingProgress (percentage);
 }
 
-KDE_NO_EXPORT void KMPlayerBrowserExtension::saveState (TQDataStream & stream) {
+TDE_NO_EXPORT void KMPlayerBrowserExtension::saveState (TQDataStream & stream) {
     stream << static_cast <PartBase *> (parent ())->url ().url ();
 }
 
-KDE_NO_EXPORT void KMPlayerBrowserExtension::restoreState (TQDataStream & stream) {
+TDE_NO_EXPORT void KMPlayerBrowserExtension::restoreState (TQDataStream & stream) {
     TQString url;
     stream >> url;
     static_cast <PartBase *> (parent ())->openURL (KURL(url));
 }
 
-KDE_NO_EXPORT void KMPlayerBrowserExtension::requestOpenURL (const KURL & url, const TQString & target, const TQString & service) {
+TDE_NO_EXPORT void KMPlayerBrowserExtension::requestOpenURL (const KURL & url, const TQString & target, const TQString & service) {
     KParts::URLArgs args;
     args.frameName = target;
     args.serviceType = service;
     emit openURLRequest (url, args);
 }
 
-KDE_NO_EXPORT void KMPlayerBrowserExtension::slotRequestOpenURL (const KURL &url, const TQString &target) {
+TDE_NO_EXPORT void KMPlayerBrowserExtension::slotRequestOpenURL (const KURL &url, const TQString &target) {
     requestOpenURL (url, target, TQString ());
 }
 
@@ -870,11 +870,11 @@ KDE_NO_CDTOR_EXPORT KMPlayerLiveConnectExtension::~KMPlayerLiveConnectExtension(
     kdDebug () << "KMPlayerLiveConnectExtension::~KMPlayerLiveConnectExtension()" << endl;
 }
 
-KDE_NO_EXPORT void KMPlayerLiveConnectExtension::started () {
+TDE_NO_EXPORT void KMPlayerLiveConnectExtension::started () {
     m_started = true;
 }
 
-KDE_NO_EXPORT void KMPlayerLiveConnectExtension::finished () {
+TDE_NO_EXPORT void KMPlayerLiveConnectExtension::finished () {
     if (m_started && m_enablefinish) {
         KParts::LiveConnectExtension::ArgList args;
         args.push_back (qMakePair (KParts::LiveConnectExtension::TypeString, TQString("if (window.onFinished) onFinished();")));
@@ -884,7 +884,7 @@ KDE_NO_EXPORT void KMPlayerLiveConnectExtension::finished () {
     }
 }
 
-KDE_NO_EXPORT void KMPlayerLiveConnectExtension::evaluate (
+TDE_NO_EXPORT void KMPlayerLiveConnectExtension::evaluate (
         const TQString & scr, TQString & result) {
     TQString script (scr);
     KParts::LiveConnectExtension::ArgList args;
@@ -902,7 +902,7 @@ KDE_NO_EXPORT void KMPlayerLiveConnectExtension::evaluate (
     result = script_result;
 }
 
-KDE_NO_EXPORT bool KMPlayerLiveConnectExtension::get
+TDE_NO_EXPORT bool KMPlayerLiveConnectExtension::get
   (const unsigned long id, const TQString & name,
    KParts::LiveConnectExtension::Type & type,
    unsigned long & rid, TQString & rval)
@@ -942,7 +942,7 @@ KDE_NO_EXPORT bool KMPlayerLiveConnectExtension::get
     return true;
 }
 
-KDE_NO_EXPORT bool KMPlayerLiveConnectExtension::put
+TDE_NO_EXPORT bool KMPlayerLiveConnectExtension::put
   (const unsigned long, const TQString & name, const TQString & val) {
     if (name == "__kmplayer__res") {
         script_result = val;
@@ -973,7 +973,7 @@ KDE_NO_EXPORT bool KMPlayerLiveConnectExtension::put
     return true;
 }
 
-KDE_NO_EXPORT bool KMPlayerLiveConnectExtension::call
+TDE_NO_EXPORT bool KMPlayerLiveConnectExtension::call
   (const unsigned long id, const TQString & name,
    const TQStringList & args, KParts::LiveConnectExtension::Type & type,
    unsigned long & rid, TQString & rval) {
@@ -1091,10 +1091,10 @@ KDE_NO_EXPORT bool KMPlayerLiveConnectExtension::call
     return true;
 }
 
-KDE_NO_EXPORT void KMPlayerLiveConnectExtension::unregister (const unsigned long) {
+TDE_NO_EXPORT void KMPlayerLiveConnectExtension::unregister (const unsigned long) {
 }
 
-KDE_NO_EXPORT void KMPlayerLiveConnectExtension::setSize (int w, int h) {
+TDE_NO_EXPORT void KMPlayerLiveConnectExtension::setSize (int w, int h) {
     KMPlayer::View * view = static_cast <KMPlayer::View*> (player->view ());
     if (view->controlPanelMode () == KMPlayer::View::CP_Show)
         h += view->controlPanel()->height();
@@ -1116,21 +1116,21 @@ KDE_NO_CDTOR_EXPORT KMPlayerHRefSource::~KMPlayerHRefSource () {
     //kdDebug () << "KMPlayerHRefSource::~KMPlayerHRefSource" << endl;
 }
 
-KDE_NO_EXPORT void KMPlayerHRefSource::init () {
+TDE_NO_EXPORT void KMPlayerHRefSource::init () {
     Source::init ();
     setIdentified ();
 }
 
-KDE_NO_EXPORT bool KMPlayerHRefSource::hasLength () {
+TDE_NO_EXPORT bool KMPlayerHRefSource::hasLength () {
     return false;
 }
 
-KDE_NO_EXPORT bool KMPlayerHRefSource::processOutput (const TQString & /*str*/) {
+TDE_NO_EXPORT bool KMPlayerHRefSource::processOutput (const TQString & /*str*/) {
     //return Source::processOutput (str);
     return true;
 }
 
-KDE_NO_EXPORT void KMPlayerHRefSource::setURL (const KURL & url) {
+TDE_NO_EXPORT void KMPlayerHRefSource::setURL (const KURL & url) {
     m_url = url;
     m_identified = false;
     m_finished = false;
@@ -1138,7 +1138,7 @@ KDE_NO_EXPORT void KMPlayerHRefSource::setURL (const KURL & url) {
     kdDebug () << "KMPlayerHRefSource::setURL " << m_url.url() << endl;
 }
 
-KDE_NO_EXPORT void KMPlayerHRefSource::play () {
+TDE_NO_EXPORT void KMPlayerHRefSource::play () {
     kdDebug () << "KMPlayerHRefSource::play " << m_url.url() << endl;
     Source * src = m_player->sources () ["urlsource"];
     TQString target = src->document ()->document ()->
@@ -1150,7 +1150,7 @@ KDE_NO_EXPORT void KMPlayerHRefSource::play () {
         m_player->setSource (m_player->sources () ["urlsource"]);
 }
 
-KDE_NO_EXPORT void KMPlayerHRefSource::activate () {
+TDE_NO_EXPORT void KMPlayerHRefSource::activate () {
     m_player->stop ();
     if (m_finished) {
         TQTimer::singleShot (0, this, TQ_SLOT (finished ()));
@@ -1167,18 +1167,18 @@ KDE_NO_EXPORT void KMPlayerHRefSource::activate () {
     }
 }
 
-KDE_NO_EXPORT void KMPlayerHRefSource::clear () {
+TDE_NO_EXPORT void KMPlayerHRefSource::clear () {
     setURL (KURL ());
 }
 
-KDE_NO_EXPORT void KMPlayerHRefSource::grabReady (const TQString & path) {
+TDE_NO_EXPORT void KMPlayerHRefSource::grabReady (const TQString & path) {
     kdDebug () << "KMPlayerHRefSource::grabReady(" << path << ")" << endl;
     m_finished = true;
     m_grabfile = path;
     finished ();
 }
 
-KDE_NO_EXPORT void KMPlayerHRefSource::finished () {
+TDE_NO_EXPORT void KMPlayerHRefSource::finished () {
     kdDebug () << "KMPlayerHRefSource::finished()" << endl;
     KMPlayer::View * view = static_cast <KMPlayer::View*> (m_player->view ());
     if (!view) return;
@@ -1191,7 +1191,7 @@ KDE_NO_EXPORT void KMPlayerHRefSource::finished () {
         connect (view, TQ_SIGNAL (pictureClicked ()), this, TQ_SLOT (play ()));
 }
 
-KDE_NO_EXPORT void KMPlayerHRefSource::deactivate () {
+TDE_NO_EXPORT void KMPlayerHRefSource::deactivate () {
     kdDebug () << "KMPlayerHRefSource::deactivate()" << endl;
     KMPlayer::View * view = static_cast <KMPlayer::View*> (m_player->view ());
     if (!view) return;
@@ -1200,7 +1200,7 @@ KDE_NO_EXPORT void KMPlayerHRefSource::deactivate () {
         disconnect (view, TQ_SIGNAL (pictureClicked ()), this, TQ_SLOT (play ()));
 }
 
-KDE_NO_EXPORT TQString KMPlayerHRefSource::prettyName () {
+TDE_NO_EXPORT TQString KMPlayerHRefSource::prettyName () {
     return i18n ("WEB");
 }
 
