@@ -33,15 +33,15 @@ class ViewAreaPrivate;
  * The area in which the video widget and controlpanel are laid out
  */
 class KMPLAYER_EXPORT ViewArea : public TQWidget {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     ViewArea (TQWidget * parent, View * view);
     ~ViewArea ();
-    KDE_NO_EXPORT bool isFullScreen () const { return m_fullscreen; }
-    KDE_NO_EXPORT bool isMinimalMode () const { return m_minimal; }
-    KDE_NO_EXPORT TDEActionCollection * actionCollection () const { return m_collection; }
-    KDE_NO_EXPORT TQRect topWindowRect () const { return m_topwindow_rect; }
+    TDE_NO_EXPORT bool isFullScreen () const { return m_fullscreen; }
+    TDE_NO_EXPORT bool isMinimalMode () const { return m_minimal; }
+    TDE_NO_EXPORT TDEActionCollection * actionCollection () const { return m_collection; }
+    TDE_NO_EXPORT TQRect topWindowRect () const { return m_topwindow_rect; }
     SurfacePtr getSurface (NodePtr node);
     void setAudioVideoGeometry (const IRect &rect, unsigned int * bg);
     void setAudioVideoNode (NodePtr n);
