@@ -25,7 +25,7 @@
 #include <tqsessionmanager.h>
 
 class KXVideoPlayer : public TQApplication {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KXVideoPlayer (int argc, char ** argv);
